@@ -979,7 +979,9 @@ magui_magnification_options_save_changed (void)
 	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_lock_factor));
 	    
     magnifier_setting->zoomfactorx	= 
-	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_factorx));
+	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factorx));
+
+    g_message ("zoom factor x = %f", magnifier_setting->zoomfactorx);
 	
     if (magnifier_setting->zoomfactor_lock)
     {
@@ -988,7 +990,7 @@ magui_magnification_options_save_changed (void)
     else
     {
 	magnifier_setting->zoomfactory	= 
-	    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_factory));
+	    gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factory));
     }
     
     magnifier_setting->invert = 
@@ -1311,15 +1313,15 @@ on_change_sp1_value	(GtkWidget       *widget,
         	        gpointer         user_data)
 {
 
-    gint ival =
+    gdouble dval =
 	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factorx));
 	
-    if (ival == magnifier_setting->zoomfactorx) 
+    if (dval == magnifier_setting->zoomfactorx) 
 	return;
 
     if (magnifier_setting->zoomfactor_lock)
     {
-	magnifier_setting->zoomfactorx = ival;
+	magnifier_setting->zoomfactorx = dval;
 	    		
 	magnifier_setting->zoomfactory = 
 	    magnifier_setting->zoomfactorx ;
@@ -1328,20 +1330,20 @@ on_change_sp1_value	(GtkWidget       *widget,
 				magnifier_setting->zoomfactory);		
 	
 	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
+				    GCONF_VALUE_FLOAT,
 				    MAGNIFIER_ZOOM_FACTOR_Y,
 				    (gpointer)&magnifier_setting->zoomfactory);
 	
 	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
+				    GCONF_VALUE_FLOAT,
 				    MAGNIFIER_ZOOM_FACTOR_X,
 				    (gpointer)&magnifier_setting->zoomfactorx);
     }
     else
     {
-	magnifier_setting->zoomfactorx = ival;
+	magnifier_setting->zoomfactorx = dval;
 	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
+				    GCONF_VALUE_FLOAT,
 				    MAGNIFIER_ZOOM_FACTOR_X,
 				    (gpointer)&magnifier_setting->zoomfactorx);
     }
@@ -1351,16 +1353,15 @@ void
 on_change_sp2_value	(GtkWidget       *widget,
         	        gpointer         user_data)
 {
-    gint ival =
+    gdouble dval =
 	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factory));
 	
-    if (ival == magnifier_setting->zoomfactory) 
+    if (dval == magnifier_setting->zoomfactory) 
 	return;
-
     
     if (magnifier_setting->zoomfactor_lock)
     {
-	magnifier_setting->zoomfactorx = ival;
+	magnifier_setting->zoomfactorx = dval;
 		
 	magnifier_setting->zoomfactory = 
 	    magnifier_setting->zoomfactorx ;
@@ -1369,20 +1370,20 @@ on_change_sp2_value	(GtkWidget       *widget,
 		magnifier_setting->zoomfactorx);		
 	
 	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
+				    GCONF_VALUE_FLOAT,
 				    MAGNIFIER_ZOOM_FACTOR_Y,
 				    (gpointer)&magnifier_setting->zoomfactory);
 	
 	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
+				    GCONF_VALUE_FLOAT,
 				    MAGNIFIER_ZOOM_FACTOR_X,
 				    (gpointer)&magnifier_setting->zoomfactorx);
     }
     else
     {
-	magnifier_setting->zoomfactory = ival;
+	magnifier_setting->zoomfactory = dval;
 	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
+				    GCONF_VALUE_FLOAT,
 				    MAGNIFIER_ZOOM_FACTOR_Y,
 				    (gpointer)&magnifier_setting->zoomfactory);
 
@@ -1404,7 +1405,7 @@ magui_change_lock_factor(GtkWidget       *widget,
     
     magnifier_setting->zoomfactorx = 
 	magnifier_setting->zoomfactory = (  magnifier_setting->zoomfactory + 
-					    magnifier_setting->zoomfactorx) >> 1;
+					    magnifier_setting->zoomfactorx) / 2.0;
 				
     gtk_spin_button_set_value   (GTK_SPIN_BUTTON (sp_factorx), 
 				magnifier_setting->zoomfactorx);
@@ -1418,12 +1419,12 @@ magui_change_lock_factor(GtkWidget       *widget,
 				(gpointer)&magnifier_setting->zoomfactor_lock);
 	
     magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_INT,
+				GCONF_VALUE_FLOAT,
 				MAGNIFIER_ZOOM_FACTOR_Y,
 				(gpointer)&magnifier_setting->zoomfactory);
 	
     magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_INT,
+				GCONF_VALUE_FLOAT,
 				MAGNIFIER_ZOOM_FACTOR_X,
 				(gpointer)&magnifier_setting->zoomfactorx);				
 }
