@@ -22,33 +22,11 @@
 #define _SPGSCB_H_
 
 
-#include <bonobo/bonobo-object.h>
 #include <gnome-speech/gnome-speech.h>
 
-#define CALLBACK_TYPE        (callback_get_type ())
-#define CALLBACK(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), CALLBACK_TYPE, CALLBACK))
-#define CALLBACK_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), CALLBACK_TYPE, CallbackClass))
-#define IS_CALLBACK(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), CALLBACK_TYPE))
-#define IS_CALLBACK_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CALLBACK_TYPE))
-
-typedef void (* GSCB)(int reason, gpointer user_data);
-
-typedef struct 
-{
-    BonoboObject parent;
-} Callback;
-
-typedef struct 
-{
-  BonoboObjectClass 			parent_class;
-  POA_GNOME_Speech_SpeechCallback__epv	epv;
-} CallbackClass;
-
-GType
-callback_get_type (void);
-
-Callback *
-callback_new (gpointer	client_callback, 
-	      gpointer	client_data);
+typedef void (*SRSGSMarkersCallback) (GNOME_Speech_speech_callback_type type, 
+					CORBA_long text_id, CORBA_long offset);
+gboolean srs_gs_cb_register_callback (GNOME_Speech_Speaker speaker,
+					    SRSGSMarkersCallback callback);
 
 #endif  /* _SPGSCB_H_ */
